@@ -8,19 +8,9 @@
 from inspect import getargspec
 import os
 import sys
-import traceback
-from pkg_resources import parse_version
 
 from contextlib import contextmanager
 
-try:
-    from pdb import Restart
-except ImportError:
-    class Restart(Exception):
-        pass
-
-import IPython
-
 
 def import_module(possible_modules, needed_module):
     """Make it more resilient to different versions of IPython and try to
@@ -34,77 +24,45 @@ def import_module(possible_modules, needed_module):
             if count == 0:
                 raise
 
-if parse_version(IPython.__version__) > parse_version('0.10.2'):
-    from IPython.core.debugger import Pdb, BdbQuit_excepthook
+from IPython.core.debugger import Pdb, BdbQuit_excepthook
 
-    possible_modules = ['IPython.terminal.ipapp',           # Newer IPython
-                        'IPython.frontend.terminal.ipapp']  # Older IPython
+possible_modules = ['IPython.terminal.ipapp',           # Newer IPython
+                    'IPython.frontend.terminal.ipapp']  # Older IPython
 
-    app = import_module(possible_modules, "TerminalIPythonApp")
-    TerminalIPythonApp = app.TerminalIPythonApp
+app = import_module(possible_modules, "TerminalIPythonApp")
+TerminalIPythonApp = app.TerminalIPythonApp
 
-    possible_modules = ['IPython.terminal.embed',           # Newer IPython
-                        'IPython.frontend.terminal.embed']  # Older IPython
-    embed = import_module(possible_modules, "InteractiveShellEmbed")
-    InteractiveShellEmbed = embed.InteractiveShellEmbed
-    try:
-        get_ipython
-    except NameError:
-        # Build a terminal app in order to force ipython to load the
-        # configuration
-        ipapp = TerminalIPythonApp()
-        # Avoid output (banner, prints)
-        ipapp.interact = False
-        ipapp.initialize([])
-        def_colors = ipapp.shell.colors
-    else:
-        # If an instance of IPython is already running try to get an instance
-        # of the application. If there is no TerminalIPythonApp instanciated
-        # the instance method will create a new one without loading the config.
-        # i.e: if we are in an embed instance we do not want to load the config.
-        ipapp = TerminalIPythonApp.instance()
-        shell = get_ipython()
-        def_colors = shell.colors
-
-        # Detect if embed shell or not and display a message
-        if isinstance(shell, InteractiveShellEmbed):
-            shell.write_err(
-                "\nYou are currently into an embedded ipython shell,\n"
-                "the configuration will not be loaded.\n\n"
-            )
-
-    def_exec_lines = [line + '\n' for line in ipapp.exec_lines]
-
-    from IPython.utils import io
-
-    if 'nose' in list(sys.modules.keys()):
-        def update_stdout():
-            # setup stdout to ensure output is available with nose
-            io.stdout = sys.stdout = sys.__stdout__
-    else:
-        def update_stdout():
-            pass
+possible_modules = ['IPython.terminal.embed',           # Newer IPython
+                    'IPython.frontend.terminal.embed']  # Older IPython
+embed = import_module(possible_modules, "InteractiveShellEmbed")
+InteractiveShellEmbed = embed.InteractiveShellEmbed
+try:
+    get_ipython
+except NameError:
+    # Build a terminal app in order to force ipython to load the
+    # configuration
+    ipapp = TerminalIPythonApp()
+    # Avoid output (banner, prints)
+    ipapp.interact = False
+    ipapp.initialize([])
+    def_colors = ipapp.shell.colors
 else:
-    from IPython.Debugger import Pdb, BdbQuit_excepthook
-    from IPython.Shell import IPShell
-    from IPython import ipapi
+    # If an instance of IPython is already running try to get an instance
+    # of the application. If there is no TerminalIPythonApp instanciated
+    # the instance method will create a new one without loading the config.
+    # i.e: if we are in an embed instance we do not want to load the config.
+    ipapp = TerminalIPythonApp.instance()
+    shell = get_ipython()
+    def_colors = shell.colors
 
-    ip = ipapi.get()
-    if ip is None:
-        IPShell(argv=[''])
-        ip = ipapi.get()
-    def_colors = ip.options.colors
-    def_exec_lines = []
+    # Detect if embed shell or not and display a message
+    if isinstance(shell, InteractiveShellEmbed):
+        shell.write_err(
+            "\nYou are currently into an embedded ipython shell,\n"
+            "the configuration will not be loaded.\n\n"
+        )
 
-    from IPython.Shell import Term
-
-    if 'nose' in list(sys.modules.keys()):
-        def update_stdout():
-            # setup stdout to ensure output is available with nose
-            Term.cout = sys.stdout = sys.__stdout__
-    else:
-        def update_stdout():
-            pass
+def_exec_lines = [line + '\n' for line in ipapp.exec_lines]
 
 
 def _init_pdb(context=3):
@@ -125,7 +83,6 @@ def wrap_sys_excepthook():
 
 
 def set_trace(frame=None, context=3):
-    update_stdout()
     wrap_sys_excepthook()
     if frame is None:
         frame = sys._getframe().f_back
@@ -135,7 +92,6 @@ def set_trace(frame=None, context=3):
 
 
 def post_mortem(tb=None):
-    update_stdout()
     wrap_sys_excepthook()
     p = _init_pdb()
     p.reset()
@@ -176,6 +132,14 @@ def launch_ipdb_on_exception():
 
 
 def main():
+    import traceback
+    import sys
+    try:
+        from pdb import Restart
+    except ImportError:
+        class Restart(Exception):
+            pass
+
     if not sys.argv[1:] or sys.argv[1] in ("--help", "-h"):
         print("usage: ipdb.py scriptfile [arg] ...")
         sys.exit(2)
